import signal
import subprocess
import time

from utils import utils


class Stan:

    def __init__(self, time, command):
        self.time = time
        self.command = command

    def broken_alarm(self):
        time.sleep(self.time)

    def register_signals(self):
        signal.signal(signal.SIGINT, utils.signal_handler)

    def answer(self):
        if self.command == ['']:
            print("[STAN] Attends, j'appelle Bruno !")
            print('[BRUNO] ', end='')
            utils.bruno()
        else:
            subprocess.run(self.command)

    def run(self):
        self.register_signals()
        self.broken_alarm()
        self.answer()



import setuptools
from stancmd import version

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='stancmd',
    version=version,
    description='A useless command line patience tester',
    url='https://gitlab.com/quentin-dev/stan',
    author='Quentin Barbarat',
    author_email='q.barbarat@gmail.com',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    install_requires=[],
    entry_points={
        'console_scripts': ['stancmd=stancmd.main:main'],
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.7',
)



def bruno():
    print('Va voir ce que dit le standard CPP17 : http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/n4713.pdf')


def signal_handler(signum, frame):
    print(f'[STAN] Désolé mon réveil était cassé...')
    return
